@@ -26,7 +26,7 @@ from pyplan_core.classes.PyplanFunctions import PyplanFunctions, Selector
 from pyplan_core.classes.wizards import (CalculatedField, DataarrayFromPandas,
                                          DataframeGroupby, DataframeIndex,
                                          InputTable, SelectColumns, SelectRows,
-                                         sourcecsv, CreateIndex, IndexFromPandas, DataArrayFilter)
+                                         sourcecsv, CreateIndex, IndexFromPandas, DataArrayFilter, RenameIndexItem)
 
 from .DefaultNodeFormats import default_formats
 
@@ -1328,7 +1328,7 @@ class Model(object):
         path_arr = fileName[:fileName.rfind(path_sep)].split(path_sep)
 
         dest_path = path_sep.join(
-            path_arr[:6 if path_arr[4] == 'Workgroups' else 5])
+            path_arr[:6 if path_arr[4] == 'Teams' else 5])
 
         # Get python folder path
         python_folder = f'python{sys.version[:3]}'
@@ -1351,9 +1351,9 @@ class Model(object):
             # copy base venv folders
             os.system(f'cp -r -u {venv_path}-bkp/* {user_lib_path}')
 
-            # create symlink from user /public site-package
-            os.system(f'rm -rf {venv_path}')
-            os.system(f'ln -s -f {user_lib_path} {venv_path}')
+        # create symlink from user /public site-package
+        os.system(f'rm -rf {venv_path}')
+        os.system(f'ln -s -f {user_lib_path} {venv_path}')
 
     def applyBackwardCompatibility(self):
         # update old selector definition
@@ -1547,6 +1547,8 @@ class Model(object):
             return IndexFromPandas.Wizard()
         elif key == 'dataarrayfilter':
             return DataArrayFilter.Wizard()
+        elif key == 'renameindexitem':
+            return RenameIndexItem.Wizard()
         
 
     def getSystemResources(self, onlyMemory=False):
